@@ -5,6 +5,7 @@ use nom::{
     number::complete::*,
 };
 use std::borrow::Cow;
+use std::mem::size_of;
 use tracing::debug;
 
 #[derive(Copy, Clone, Debug)]
@@ -49,6 +50,7 @@ fn read_value(
         return Err(nom::Err::Failure(VerboseError { errors }));
     }
     if input.len() < data_len {
+        tracing::trace!("{} < {}", input.len(), data_len);
         return Err(nom::Err::Failure(VerboseError::from_error_kind(
             &input[input.len()..],
             ErrorKind::Eof,
@@ -74,6 +76,13 @@ fn read_value(
             break;
         }
         input = bytes;
+        if size_of::<u64>().saturating_mul(counts_len as usize) > input.len() {
+            let errors = vec![(
+                input,
+                VerboseErrorKind::Context("hash_table value count length exceeds length of input"),
+            )];
+            return Err(nom::Err::Failure(VerboseError { errors }));
+        }
         for _ in 0..counts_len {
             let (bytes, count) = le_u64(input)?;
             input = bytes;
@@ -84,34 +93,45 @@ fn read_value(
             break;
         }
 
-        // If the version is > v2 then there can also be value profiling data so lets try and parse
-        // that now
-        let (bytes, total_size) = le_u32(input)?;
-        if bytes.len() <= end_len {
-            break;
+        if version > 10 {
+            let (bytes, bitmap_bytes) = le_u64(input)?;
+            input = bytes;
+            for _i in 0..bitmap_bytes {
+                let (bytes, _) = le_u64(input)?;
+                input = bytes;
+            }
         }
-        let (bytes, num_value_kinds) = le_u32(bytes)?;
-        // Here it's just less than because we don't need to read anything else so if it's equal to
-        // we're good
-        if bytes.len() < end_len {
-            break;
-        }
-        input = bytes;
-        let value_prof_data = ValueProfData {
-            total_size,
-            num_value_kinds,
-        };
-        if value_prof_data.num_value_kinds > 0 && version > 2 {
-            // If we actually want to change data in future get result.last_mut() and change it
-            // there
-            break;
+        // This should always be true
+        if version > 2 {
+            // If the version is > v2 then there can also be value profiling data so lets try and parse
+            // that now
+            let (bytes, total_size) = le_u32(input)?;
+            if bytes.len() <= end_len {
+                break;
+            }
+            let (bytes, num_value_kinds) = le_u32(bytes)?;
+            // Here it's just less than because we don't need to read anything else so if it's equal to
+            // we're good
+            if bytes.len() < end_len {
+                break;
+            }
+            input = bytes;
+            let value_prof_data = ValueProfData {
+                total_size,
+                num_value_kinds,
+            };
+            if value_prof_data.num_value_kinds > 0 && version > 2 {
+                // If we actually want to change data in future get result.last_mut() and change it
+                // there
+                break;
+            }
         }
     }
     if result.is_empty() {
         result.push((last_hash, InstrProfRecord::default()));
     }
     input = expected_end;
-    assert_eq!(result.len(), 1);
+    assert!(!result.is_empty());
     Ok((input, result.remove(0)))
 }
 
@@ -133,6 +153,7 @@ impl HashTable {
         debug!("Number of hashtable buckets: {}", num_buckets);
         let (_bytes, mut num_entries) = le_u64(bytes)?;
         debug!("Number of entries: {}", num_entries);
+
         let mut payload = input;
         let mut result = Self::new();
         //TODO is this change right?
@@ -151,7 +172,11 @@ impl HashTable {
         mut num_entries: u64,
     ) -> ParseResult<'a, u64> {
         let (bytes, num_items_in_bucket) = le_u16(input)?;
-        debug!("Number of items in bucket: {}", num_items_in_bucket);
+        debug!(
+            "Number of items in bucket: {}, input remaining: {}",
+            num_items_in_bucket,
+            input.len()
+        );
         let mut remaining = bytes;
         for _i in 0..num_items_in_bucket {
             let (bytes, _hash) = le_u64(remaining)?;
